/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*- */

#include "framecpp/Common/StringStream.hh"
#include "framecpp/Common/DynamicMemoryBuffer.hh"

namespace FrameCPP
{
  namespace Common
  {
    //-------------------------------------------------------------------
    /// The default constructor will initialize all the parts used
    /// in the general case.
    //-------------------------------------------------------------------
    DynamicMemoryBuffer::
    DynamicMemoryBuffer( bool ParentAutoDelete )
      : MemoryBuffer( std::ios::in, ParentAutoDelete )
    {
    }

    //-------------------------------------------------------------------
    /// Be careful to release all the resources that were created
    /// for this object.
    //-------------------------------------------------------------------
    DynamicMemoryBuffer::
    ~DynamicMemoryBuffer( )
    {
    }

    //-------------------------------------------------------------------
    //-------------------------------------------------------------------
    void DynamicMemoryBuffer::
    NextBlock( const char* Buffer, size_type Size )
    {
      scanner_type::NextBlock( Buffer, Size );
      //-----------------------------------------------------------------
      // Copy the bytes to the temporary output buffer
      //-----------------------------------------------------------------
      accumulated_buffer.write( Buffer, Size );
      if ( Ready( ) )
      {
        str( accumulated_buffer.str( ) );
      }
    }

    //-------------------------------------------------------------------
    //-------------------------------------------------------------------
    void DynamicMemoryBuffer::
    Reset( )
    {
      //-----------------------------------------------------------------
      // Seek to the beginning of the buffer;
      //-----------------------------------------------------------------
      accumulated_buffer.seekp( std::streampos( 0 ) );
      scanner_type::Reset( );
    }
  } // namespace Common

} // namespace FrameCPP
